@@ -1,5 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
+import math
+
 from refinery.units import Arg, Unit
 from refinery.lib.argformats import numseq
 
@@ -22,10 +24,16 @@ class base(Unit):
             R'Either the base to be used or an alphabet. If an explicit alphabet is given, its length '
             R'determines the base. The default base 0 treats the input as a Python integer literal. If '
             F'a numeric base is given, digits from the alphabet "{_DEFAULT_ALPH_STR}" are used. ')) = 0,
+        strip_padding: Arg.Switch('-s', help='Do not add leading zeros to the output.') = False,
         little_endian: Arg.Switch('-e', help='Use little endian byte order instead of big endian.') = False,
-        strict_digits: Arg.Switch('-s', help='Check that all input digits are part of the alphabet.') = False,
+        strict_digits: Arg.Switch('-d', help='Check that all input digits are part of the alphabet.') = False,
     ):
-        super().__init__(base=base, little_endian=little_endian, strict_digits=strict_digits)
+        super().__init__(
+            base=base,
+            strip_padding=strip_padding,
+            little_endian=little_endian,
+            strict_digits=strict_digits,
+        )
 
     @property
     def _args(self):
@@ -51,19 +59,24 @@ class base(Unit):
         self.log_info('using byte order', self.byteorder)
         number = int.from_bytes(data, byteorder=self.byteorder)
 
-        if number == 0:
-            return B'0'
         if base == 0:
             return B'0x%X' % number
         if base > len(alphabet):
             raise ValueError(F'Only {len(alphabet)} available; not enough to encode base {base}')
 
-        def reverse_result(number):
-            while number:
-                yield alphabet[number % base]
-                number //= base
+        data_bits = len(data) * 8
+        base_bits = math.log2(base)
+        result = bytearray()
 
-        return bytes(reversed(tuple(reverse_result(number))))
+        while data_bits >= 1:
+            number, k = divmod(number, base)
+            result.append(alphabet[k])
+            if not number and self.args.strip_padding:
+                break
+            data_bits -= base_bits
+
+        result.reverse()
+        return result
 
     def process(self, data: bytearray):
         base, alphabet = self._args
@@ -102,10 +115,14 @@ class base(Unit):
         else:
             self.log_warn('very long alphabet, unable to use built-ins; reverting to (slow) fallback.')
             result = 0
-            alphabet = {digit: k for k, digit in enumerate(alphabet)}
+            lookup = {digit: k for k, digit in enumerate(alphabet)}
             for digit in data:
                 result *= base
-                result += alphabet[digit]
-        size, rest = divmod(result.bit_length(), 8)
-        size += int(bool(rest))
+                result += lookup[digit]
+        if not base or self.args.strip_padding:
+            size, rest = divmod(result.bit_length(), 8)
+            size += int(bool(rest))
+        else:
+            size = (len(data) - 1 + alphabet.index(data[0]) / base) * math.log2(base) / 8
+            size = math.ceil(size)
         return result.to_bytes(size, byteorder=self.byteorder)
