@@ -25,7 +25,10 @@ class xtpdf(PathExtractorUnit):
 
     def _walk(self, blob, memo: Optional[Set[int]] = None, *path):
         while isinstance(blob, self._pypdf2.generic.IndirectObject):
-            blob = blob.getObject()
+            try:
+                blob = blob.getObject()
+            except Exception:
+                break
         if memo is None:
             memo = {id(blob)}
         elif id(blob) in memo:
@@ -94,7 +97,7 @@ class xtpdf(PathExtractorUnit):
                 yield from self._walk(value, memo, *path, key)
 
     def unpack(self, data):
-        with MemoryFile(data) as stream:
+        with MemoryFile(data, read_as_bytes=True) as stream:
             with NoLogging():
                 pdf = self._pypdf2.PdfFileReader(stream)
                 catalog = pdf.trailer['/Root']
